package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZfwz;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcZxyh;
import com.ruoyi.tcZz.service.ITcZxyhService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 最新隐患Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "最新隐患")
@RequestMapping("/tcZz/networkSecurity/zxyh")
public class TcZxyhController extends BaseController {
    @Autowired
    private ITcZxyhService tcZxyhService;

    /**
     * 查询最新隐患列表
     */
    @ApiOperation(value = "查询最新隐患列表", response = TcZxyh.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZxyh tcZxyh) {
        startPage();
        List<TcZxyh> list = tcZxyhService.selectTcZxyhList(tcZxyh);
        return getDataTable(list);
    }

    /**
     * 导出最新隐患列表
     */
    @ApiOperation(value = "导出最新隐患列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZxyh tcZxyh) {
        List<TcZxyh> list = tcZxyhService.selectTcZxyhList(tcZxyh);
        ExcelUtil<TcZxyh> util = new ExcelUtil<TcZxyh>(TcZxyh.class);
        util.exportExcel(response, list, "最新隐患数据");
    }

    /**
     * 获取最新隐患详细信息
     */
    @ApiOperation(value = "获取最新隐患详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZxyhService.selectTcZxyhById(id));
    }

    /**
     * 新增最新隐患
     */
    @ApiOperation(value = "新增最新隐患")
    @PostMapping
    public AjaxResult add(@RequestBody TcZxyh tcZxyh) {
        return toAjax(tcZxyhService.insertTcZxyh(tcZxyh));
    }

    /**
     * 修改最新隐患
     */
    @ApiOperation(value = "修改最新隐患")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZxyh tcZxyh) {
        return toAjax(tcZxyhService.updateTcZxyh(tcZxyh));
    }

    /**
     * 删除最新隐患
     */
    @ApiOperation(value = "删除最新隐患")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZxyhService.deleteTcZxyhByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZxyh> util = new ExcelUtil<TcZxyh>(TcZxyh.class);
        List<TcZxyh> tcZxyhList = util.importExcel(file.getInputStream());
        tcZxyhService.importUser(tcZxyhList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcZxyhService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZxyh> util = new ExcelUtil<TcZxyh>(TcZxyh.class);
        util.importTemplateExcel(response, " 最新隐患");
    }
}
